==> zen-cortex-8.0.3.tgz: package/utils/index.js <==
export * from "./core";

/**
 * Check if authentified user can perform given operation.
 * @param {object} settings - User settings state.
 * @param {string} op - Operation to look for.
 * @param {string} type - Type to look for.
 * @returns {bool} True if authorized.
 */
export function canPerformOp(settings, op, type) {
  const { PrmDefs } = settings;
  if (op && PrmDefs) {
    const { UserOps, EntityTypeOps } = PrmDefs;

    //case type operation
    if (type && EntityTypeOps) {
      const bitField = PrmDefs.EntityTypes[type.Kind][type.Id];
      const flag = EntityTypeOps[op];

      if (flag !== undefined && bitField) {
        return (bitField.Uop & (1 << flag)) > 0;
      }
      return false;
    }

    //case user operation
    return UserOps && UserOps.indexOf(op) !== -1;
  }
  return false;
}

//add default PNG extention if no extention provided
function defaultExtention(path, ext = ".png") {
  return path.split(".").pop() === path ? `${path}${ext}` : path;
}

/**
 * Compute full path to iconography element.
 * @param {object} session - Session state.
 * @param {string} path - Relative suffixed path.
 * @param {string} [defaultPath] - Path to be used as fallback.
 * @returns {string} Image full path.
 */
export function getIconographyPath(session, path, defaultPath = null) {
  if (path) return `/iconography/${session.instance}/${defaultExtention(path)}`;
  //get default image if existing
  return defaultPath ? `/images/zen/${defaultExtention(defaultPath)}` : "";
}

/**
 * Retrieve option value, or use default one otherwise
 * @param {object} settings - Settings state.
 * @param {string} key - Option key.
 * @param {string} defaultValue - Value to be used as defaut option.
 * @returns {string} Option value.
 */
export function getOptionValue(settings, key, defaultValue = "") {
  const { Options } = settings;
  return Options ? Options[key] || defaultValue : defaultValue;
}

==> zen-cortex-8.3.0.tgz: package/utils/index.js <==
export * from "./core";

/**
 * Check if authentified user can perform given operation.
 * @param {object} settings - User settings state.
 * @param {string} op - Operation to look for.
 * @param {string} type - Type to look for.
 * @returns {bool} True if authorized.
 */
export function canPerformOp(settings, op, type) {
  const { PrmDefs } = settings;
  if (op && PrmDefs) {
    const { UserOps, EntityTypeOps } = PrmDefs;

    //case type operation
    if (type && EntityTypeOps) {
      const typeDico = PrmDefs.EntityTypes[type.Kind];
      if (typeDico) {
        const bitField = typeDico[type.Id];
        const flag = EntityTypeOps[op];

        if (flag !== undefined && bitField) {
          return (bitField.Uop & (1 << flag)) > 0;
        }
      }
      return false;
    }

    //case user operation
    return UserOps && UserOps.indexOf(op) !== -1;
  }
  return false;
}

//add default PNG extention if no extention provided
function defaultExtention(path, ext = ".png") {
  return path.split(".").pop() === path ? `${path}${ext}` : path;
}

/**
 * Compute full path to iconography element.
 * @param {object} session - Session state.
 * @param {string} path - Relative suffixed path.
 * @param {string} [defaultPath] - Path to be used as fallback.
 * @returns {string} Image full path.
 */
export function getIconographyPath(session, path, defaultPath = null) {
  if (path) return `/iconography/${session.instance}/${defaultExtention(path)}`;
  //get default image if existing
  return defaultPath ? `/images/zen/${defaultExtention(defaultPath)}` : "";
}

/**
 * Retrieve option value, or use default one otherwise
 * @param {object} settings - Settings state.
 * @param {string} key - Option key.
 * @param {string} defaultValue - Value to be used as defaut option.
 * @returns {string} Option value.
 */
export function getOptionValue(settings, key, defaultValue = "") {
  const { Options } = settings;
  return Options ? Options[key] || defaultValue : defaultValue;
}
